"use strict";
/**
 * Copyright 2021 Leroy Merlin Vostok LLC
 *
 * Use of this source code is governed by a MIT-style
 * license that can be found in the LICENSE file or at
 * https://opensource.org/licenses/MIT.
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PinoLoggerService = void 0;
const common_1 = require("@nestjs/common");
const nestjs_async_hooks_1 = require("@leroymerlin/nestjs-async-hooks");
const pino_logger_1 = require("./pino-logger");
let PinoLoggerService = class PinoLoggerService {
    constructor(logger, asyncHooksContext) {
        this.logger = logger;
        this.asyncHooksContext = asyncHooksContext;
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getMessage(messageContainer, contextValue = 'Logger') {
        let messageWithContext = `[${contextValue}]`;
        if (typeof messageContainer === 'string') {
            messageWithContext += ` ${messageContainer}`;
        }
        return messageWithContext;
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getLogObject(messageContainer) {
        const traceId = this.asyncHooksContext.get('traceId');
        if (typeof traceId !== 'string') {
            return typeof messageContainer !== 'string' ? messageContainer : null;
        }
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const logObject = { traceId };
        if (typeof messageContainer !== 'string') {
            Object.defineProperty(logObject, 'value', {
                value: messageContainer,
                writable: false,
                enumerable: true,
                configurable: false,
            });
        }
        return logObject;
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    error(messageContainer, stackTrace, contextValue) {
        const messageWithContext = this.getMessage(messageContainer, contextValue);
        const logObject = this.getLogObject(messageContainer);
        this.logger.error(logObject, stackTrace, messageWithContext);
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    log(messageContainer, contextValue) {
        const messageWithContext = this.getMessage(messageContainer, contextValue);
        const logObject = this.getLogObject(messageContainer);
        this.logger.log(logObject, messageWithContext);
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    warn(messageContainer, contextValue) {
        const messageWithContext = this.getMessage(messageContainer, contextValue);
        const logObject = this.getLogObject(messageContainer);
        this.logger.warn(logObject, messageWithContext);
    }
};
PinoLoggerService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [pino_logger_1.PinoLogger,
        nestjs_async_hooks_1.AsyncHooksContext])
], PinoLoggerService);
exports.PinoLoggerService = PinoLoggerService;
